---
title: Test Coverage Parameters
url: /analysis/test-coverage/test-coverage-parameters/
---

_Test coverage reports_ describe the percentage of your code that has been tested by your test suite during a build.

This differs from _test execution reports_, which describe which tests within your test suite have been run during a build. For details, see [Test Execution Parameters](/analysis/test-coverage/test-execution-parameters/).

Test coverage reports are not generated by SonarQube itself.
They must be generated by an external tool and then imported into SonarQube by specifying a parameter telling the scanner where to look for the report.
The data is then displayed in your SonarQube analysis.

Below, you will find language- and tool-specific analysis parameters for importing test coverage reports.

For information on analysis parameters in general, see [Analysis Parameters](/analysis/analysis-parameters/).

Unless otherwise specified, these properties require values that are relative to the project root. Some properties support the following wildcards in paths. The remarks for properties that support wildcards will mention this fact. If wildcards are not noted for a given property, then they are not supported for that property.

Symbol | Meaning
-|-
`?` | a single character
`*` | any number of characters
`**` | any number of directories


## All languages

### sonar.coverageReportPaths

Path to coverage report in the [Generic Test Data](/analysis/test-coverage/generic-test/) format.


## Apex

### sonar.apex.coverage.reportPath

Path to the `test-result-codecoverage.json` report file generated by the [`apex:test:run`](https://developer.salesforce.com/docs/atlas.en-us.sfdx_cli_reference.meta/sfdx_cli_reference/cli_reference_force_apex.htm?search_text=apex%20test#cli_reference_test_run) command of the [Salesforce CLI](https://developer.salesforce.com/tools/sfdxcli).
Note, you must have a [Salesforce DX project](https://developer.salesforce.com/docs/atlas.en-us.sfdx_dev.meta/sfdx_dev/sfdx_dev_workspace_setup.htm) set up and linked to your organization.


## C/C++/Objective-C

See [C/C++/Objective-C Test Coverage](/analysis/test-coverage/c-family-test-coverage/) for examples and details.


### sonar.cfamily.gcov.reportsPath

Path to the directory containing native `*.gcov` reports (not the XML reports generated by `gcovr`).


### sonar.cfamily.llvm-cov.reportPath

Path to the `llvm-cov` report.


### sonar.cfamily.vscoveragexml.reportsPath

Path to the Visual Studio Code Coverage report.
The path may be absolute or relative to the solution directory.
Path wildcards (see above) are supported.
Note that the `.coverage` report format must be converted to `.coveragexml` format using the tool `CodeCoverage.exe` tool in order to be imported.


### sonar.cfamily.bullseye.reportPath

Path to the report from Bullseye, version >= 8.9.63 (use the [`covxml`](http://www.bullseye.com/help/ref-covxml.html) tool)


## C#

See [.NET Test Coverage](/analysis/test-coverage/dotnet-test-coverage/) for examples and details.


### sonar.cs.vscoveragexml.reportsPaths

Comma-delimited list of paths to the coverage reports produced by Visual Studio Code Coverage or the `dotnet-coverage` tool.
Wildcards are supported.


### sonar.cs.dotcover.reportsPaths

Path to the dotCover coverage report.


### sonar.cs.opencover.reportsPaths

Path to the OpenCover or Coverlet coverage report.


## Flex

### sonar.flex.cobertura.reportPaths

Path to the Cobertura XML reports.
Multiple paths may be comma-delimited.
May be absolute or relative to the project base directory.


## Go

### sonar.go.coverage.reportPaths

Comma-delimited list of paths to coverage report files.
Wildcards are supported.


## Java/Kotlin/Scala/JVM

See [Java Test Coverage](/analysis/test-coverage/java-test-coverage/) for examples and details.


### sonar.coverage.jacoco.xmlReportPaths

Comma-delimited list of paths to JaCoCo XML coverage reports.
Wildcards are supported.


### sonar.jacoco.reportPaths

Deprecated.
Use `sonar.coverage.jacoco.xmlReportPaths`.


## JavaScript/TypeScript

See [JavaScript/TypeScript Test Coverage](/analysis/test-coverage/javascript-typescript-test-coverage/) for examples and details.


### sonar.javascript.lcov.reportPaths

Comma-delimited list of paths to LCOV coverage report files.
Paths may be absolute or relative to the project root.


## PHP

See [PHP Test Coverage](/analysis/test-coverage/php-test-coverage/) for examples and details.


### sonar.php.coverage.reportPaths

Comma-delimited list of paths to Clover XML-format coverage report files.
Paths may be absolute or relative to the project root.


## Python

See [Python Test Coverage](/analysis/test-coverage/python-test-coverage/) for examples and details.


### sonar.python.coverage.reportPaths

Comma-delimited list of paths to coverage reports in the Cobertura XML format.
Wildcards are supported.
Leave unset to use the default, `coverage-reports/*coverage-*.xml`.


## Ruby

### sonar.ruby.coverage.reportPaths

Comma-delimited list of paths to SimpleCov report files generated with the [JSON formatter](https://github.com/simplecov-ruby/simplecov#json-formatter) (available from SimpleCov 0.20).
For SimpleCov versions before 0.18, you can provide `.resultset.json` report files (though we recommend updating to 0.20 and using the JSON formatter).
Paths may be absolute or relative to the project root.


## Scala

### sonar.scala.coverage.reportPaths

Comma-delimited list of paths to `scoverage.xml` report files generated by Scoverage.


## Swift with Xcode 9.3+

You can use the [xccov-to-sonarqube-generic.sh](https://github.com/SonarSource/sonar-scanning-examples/blob/master/swift-coverage/swift-coverage-example/xccov-to-sonarqube-generic.sh) script from the [sonar-scanning-examples/swift-coverage](https://github.com/SonarSource/sonar-scanning-examples/tree/master/swift-coverage) project to convert output from Xcode 9.3's `xccov` tool to the [Generic Test Data](https://docs.sonarcloud.io/enriching/test-coverage/generic-test-data/) format.


## Swift with Xcode 7-9.2

### sonar.swift.coverage.reportPaths

Path to the report generated by `llvm-cov show`.
The path may be absolute or relative to the project root.


## VB.NET

See [.NET Test Coverage](/analysis/test-coverage/dotnet-test-coverage/) for examples and details.


### sonar.vbnet.vscoveragexml.reportsPaths

Comma-delimited list of paths to Visual Studio Code Coverage reports.
Wildcards are supported.


### sonar.vbnet.dotcover.reportsPaths

Path to dotCover coverage report.


### sonar.vbnet.opencover.reportsPaths

Path to OpenCover coverage report.
