---
title: Test Execution Parameters
url: /analysis/test-coverage/test-execution-parameters/
---

_Test execution reports_ describe which tests within your test suite have been run during a build.

This differs from _test coverage reports_, which describe the percentage of your code that has been tested by your test suite during a build.
For details, see [Test Coverage](/analysis/test-coverage/overview/).

Test execution reports are not generated by SonarQube itself.
Much like tests coverage reports, test execution reports must be generated by an external tool and then imported into SonarQube by specifying a parameter telling the scanner where to look for the report.
The data is then displayed in your SonarQube analysis.

Below, you will find language- and tool-specific analysis parameters for importing test execution reports.

For information on analysis parameters in general, see [Analysis Parameters](/analysis/analysis-parameters/).

Unless otherwise specified, these properties require values that are relative to the project root. Some properties support the following wildcards in paths. The remarks for properties that support wildcards will mention this fact. If wildcards are not noted for a given property, then they are not supported for that property.

Symbol | Meaning
-|-
`?` | a single character
`*` | any number of characters
`**` | any number of directories


## Branches only

_SonarQube only supports test execution reports for the branches of a project (including the main branch), not for pull requests._
This differs from the case with test coverage reports, where pull requests are supported.


## All languages

### sonar.testExecutionReportPaths

Comma-delimited list of paths to execution reports in the [Generic Test Data](/analysis/test-coverage/generic-test/) format.


## C/C++/Objective-C

### sonar.cfamily.cppunit.reportsPath

Path to the directory holding the [CPPUnit](https://sourceforge.net/projects/cppunit/) reports.
Note that while measures such as the number of tests are displayed at the project level, no drill-down is available.


## C#

### sonar.cs.vstest.reportsPaths

Paths to VSTest reports. Multiple paths may be comma-delimited or included via wildcards.
Note that while measures such as the number of tests are displayed at the project level, no drill-down is available.


### sonar.cs.nunit.reportsPaths

Paths to NUnit execution reports. Multiple paths may be comma-delimited or included via wildcards.
Note that while measures such as the number of tests are displayed at the project level, no drill-down is available.


### sonar.cs.mstest.reportsPaths

Paths to MSTest execution reports. Multiple paths may be comma-delimited or included via wildcards.
Note that while measures such as the number of tests are displayed at the project level, no drill-down is available.


### sonar.cs.xunit.reportsPaths

Paths to xUnit execution reports. Multiple paths may be comma-delimited or included via wildcards.
Note that while measures such as the number of tests are displayed at the project level, no drill-down is available.


## Go

### sonar.go.tests.reportPaths

Comma-delimited list of paths to unit test report files.
Paths may be absolute or relative to the project root.


## Java

### sonar.junit.reportPaths

Comma-delimited list of paths to Surefire XML-format reports.


## PHP

### sonar.php.tests.reportPath

Path to the PHPUnit unit test execution report file.
The path may be absolute or relative to the project root.


## Python

### sonar.python.xunit.reportPath

Path to unit test execution report.
Leave unset to use the default (`xunit-reports/xunit-result-*.xml`).
Path wildcards (see above) are supported.
If any paths in the report are invalid, set `sonar.python.xunit.skipDetails=true` to collect only project-level details.


## VB.NET

### sonar.vbnet.vstest.reportsPaths

Paths to VSTest execution reports.
Multiple paths may be comma-delimited or included via wildcards.
Note that while measures such as the number of tests are displayed at the project level, no drill-down is available.


### sonar.vbnet.nunit.reportsPaths

Paths to NUnit execution reports.
Multiple paths may be comma-delimited or included via wildcards.
Note that while measures such as the number of tests are displayed at the project level, no drill-down is available.


### sonar.vbnet.mstest.reportsPaths

Paths to MSTest execution reports.
Multiple paths may be comma-delimited or included via wildcards.
Note that while measures such as the number of tests are displayed at the project level, no drill-down is available.


### sonar.vbnet.xunit.reportsPaths

Paths to xUnit execution reports.
Multiple paths may be comma-delimited or included via wildcards.
Note that while measures such as the number of tests are displayed at the project level, no drill-down is available.
